@@ -84,8 +84,10 @@ class SSLClientAuthMiddleware(object):
         user = authenticate(request=request)
         if user is None or not user.is_authenticated():
             return
-        if request.META.get('X_REST_API'):
+        if int(request.META.get('HTTP_X_REST_API')):
             request.user = user
+            logger.debug("REST API call, not logging user in")
         else:
+            logger.info("Logging user in")
             login(request, user)
 
